@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2018 Montel Laurent <montel@kde.org>
+ * Copyright (c) 2011-2020 Laurent Montel <montel@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by
@@ -86,7 +86,7 @@ QSize SpellCheckLineEdit::sizeHint() const
     opt.midLineWidth = 0;
     opt.state |= QStyle::State_Sunken;
 
-    QSize s = style()->sizeFromContents(QStyle::CT_LineEdit, &opt, QSize(100, h).expandedTo(QApplication::globalStrut()), this);
+    QSize s = style()->sizeFromContents(QStyle::CT_LineEdit, &opt, QSize(100, h), this);
 
     return s;
 }
